#
# spec file for package chainguard-dfc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name dfc

Name:           chainguard-dfc
Version:        0.9.3
Release:        1.1
Summary:        Chainguard Dockerfile Converter
License:        Apache-2.0
URL:            https://github.com/chainguard-dev/dfc
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  git-core
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.24
# there is already a package called dfc...
Conflicts:      dfc

%description
CLI to convert Dockerfiles to use Chainguard Images and APKs in FROM and RUN
lines etc.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

go build \
   -mod=vendor \
   -buildmode=pie \
   -buildvcs=true \
   -trimpath \
   -o bin/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%check
%{buildroot}/%{_bindir}/%{executable_name} --version
%{buildroot}/%{_bindir}/%{executable_name} --version | grep v%{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Fri Jul  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.9.3:
  * Add dist/ to gitignore to fix version
* Fri Jul  4 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.9.2:
  * Get version and revision using runtime/debug
* Thu Jul  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.9.1:
  * Fix issue where USER root not provided with useradd
* Fri Jun 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.9.0:
  * Created Basic MCP Server for Dockerfile Converter by @rohitg00
    in #70
  * Cleanup mcp-server, add CI, add README about it by @jdolitsky
    in #93
  * feat: Add --warn-missing-packages flag to warn instead of
    silently using original package names by @iamrajiv in #96
* Mon Jun  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.8.0:
  * Add support for --platform flag in FROM lines
  * [StepSecurity] Apply security best practices
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.7.2:
  * fix linter issues
  * remove comment
  * add strict flag to force package mapping
  * [StepSecurity] Apply security best practices
* Thu May 22 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.7.1:
  * Parse debian epoch version
* Sat May 10 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.7.0:
  * Add an "about" section to readme, with links to
    edu.chainguard.dev by @scalewithlee in #69
  * Add mapping for font-liberation by @cronik in #72
  * Git ignore .idea directory by @cronik in #73
  * Add mapping for font-opensans by @cronik in #74
  * Add mapping for cairo by @cronik in #75
  * Add mapping for cups-libs by @cronik in #76
  * Add mapping for font-util by @cronik in #77
  * feat: Add RunLineConverter option to allow custom RUN line
    conversion by @iamrajiv in #68
  * Remove extra apt commands and adjust package versions by
    @cronik in #81
  * Remove package manager cache cleanup commands by @cronik in #82
* Fri May  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package chainguard-dfc: (d)ocker(f)ile (c)onverter: CLI to
  convert Dockerfiles to use Chainguard Images and APKs in FROM and
  RUN lines etc.
